#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-silver
version:              3.3.2.1
visibility:           public
id:                   tasty-silver-3.3.2.1-HA2ocENov1429SoTzmNts
key:                  tasty-silver-3.3.2.1-HA2ocENov1429SoTzmNts
license:              MIT
maintainer:           Andreas Abel, Philipp Hausmann
author:               Philipp Hausmann, Andreas Abel, Roman Cheplyaka, and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  c2df8f5ab1db2ed98bf300103567b528
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-silver-3.3.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-silver-3.3.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-silver-3.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-silver
hs-libraries:         HStasty-silver-3.3.2.1-HA2ocENov1429SoTzmNts
depends:
    ansi-terminal-1.1-EWnhDZJXy1I5W5pwBR2UDi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1
    optparse-applicative-0.18.1.0-Drsi2gM4wlG4ppHqpHKUIr
    process-1.6.19.0 process-extras-0.7.4-ByKaXwOUyhnJyx65eGyQx3
    regex-tdfa-1.3.2.5-EMaUzDKttstEI5BfFz11ci
    silently-1.2.5.4-BeJQMFrht8zIosElyGUCP7 stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-IM2bl9bLJtCFnmvQ3jLhCm
    temporary-1.3-AHYrzBcWpv98oJG4OGs0iG text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

